:tocdepth: 2

.. _authors:

Authors
=======

Aqtinstall is written and maintained by Hiroshi Miura <miurahr@linux.com>

Original qli-installer is written by Linus Jahn

Significant contributions for improvements of version 2.0 and 2.1 by David Dalcino
David also leads many developments and reviews effort after 2.0.

Significant contributions have been made by @tsteven4 for implementing support for tracking changing folder hierarchies,
and by Alexandre @Kidev Poumaroux for developing the official installer option integration.


All contributors, listed alphabetically, are:

* Adrian Eddy (fix the case of Android 6.7.0)
* Alberto Mardegan(ignore_hash option)
* Alexandre @Kidev Poumaroux (official installer option, WASM fixes for Qt6.7.x, manuals)
* Andrew Wason (support arm64)
* Andrei Yankovich (tools ifw installation)
* Aurélien Gâteau (patching to qmake)
* Benjamin O (Github Actions and more)
* Christian Hoffmann (Update mirror list)
* David Dalcino (Many improvements on CI automations, commands, tests, documents and so on)
* Doronin Stanislav (document)
* EtlamGit (log improvement)
* Fabrice Le Bars (32bit binary)
* Felix Barz (Android, Explicit extra module installation)
* Gamso (improve parsing of update.xml)
* iakov (improve wasm test cases)
* J.D. Purcell (patch Qt scripts, fix list-qt)
* Julien Marrec (mypy, type hints)
* Kyle Altendorf (7z binary path search)
* @lebarsfa (ignore_hash/hash_algorithm options)
* @lightmare (Documents)
* LuK1337 (sdktool installation)
* Martin Delille (Documents)
* Mike Tzou (Update fallback url)
* mite-user (folder index handling of download web sites)
* Mizux Seihax (Qt versions)
* Mozi (CI/workflow improvement, log format)
* Nelson Chen (CI tests)
* @nikitalita (Binary distribution)
* @pylipp (Documents)
* @Steveice10 (MacOS binary build)
* Sztergbaum Roman (Version database)
* Thomas Grainger (CLI entry point)
* @tsteven4 (fix patching, support for Qt 6.8.x, and windows_arm64)
* @xavier2k6 (Update ci/test conditions)
* Vadim Peretokin (Version database)
* Vladyslav Hnatiuk (Version database)
* @ypnos (Documents)

and many other participants and contributors.
If you find a missing name to record, please feel free to tell me.
